Quote — Poezio 0.9-dev documentation

# Quote

This plugin allows you to quote messages easily.

## Usage

/quote

  Usage: `/quote <message>`

  The message must exist. You can use autocompletion to get the message you want to quote easily.

  Example:

      /quote "Pouet"

  If the message “Pouet” exists, it will be put in the input. If not you will get a warning.

## Options

after_quote

  Default value: `[empty]`

  Text to insert after the quote. `%(nick)s` and `%(time)s` can be used to insert the nick of the user who sent the message or the time of the message.

before_quote

  Default value: `[empty]`

  Text to insert before the quote. `%(nick)s` and `%(time)s` can be used to insert the nick of the user who sent the message or the time of the message.